@@ -46,7 +46,7 @@ class HalloumiVpcAlarms(object):
                 vpn_alarm_id = (
                     f'{stack_name}'
                     'VPNConnectionAlarm'
-                    f'{node.vpn_id}'
+                    f'{node.id}'
                 )
                 vpn_connection_state = cloudwatch.Alarm(
                     scope,
